pub struct ApiSource {
pub title: String,
pub slug: String,
pub url: String,
}Expand description
A single Scalar API reference source entry.
Each temporal version boundary gets its own source so Scalar renders a version switcher in the UI.
Fields
title: Stringslug: Stringurl: StringTrait Implementations